@@ -8,48 +8,23 @@ use warnings;
 
 ######################################################################
 
-sub make_a_node {
-	my ($node_type, $model) = @_;
-	my $node = $model->new_node( $node_type );
-	$node->set_node_id( $model->get_next_free_node_id( $node_type ) );
-	$node->put_in_container( $model );
-	return( $node );
-}
-
-sub make_a_child_node {
-	my ($node_type, $pp_node, $pp_attr) = @_;
-	my $container = $pp_node->get_container();
-	my $node = $pp_node->new_node( $node_type );
-	$node->set_node_id( $container->get_next_free_node_id( $node_type ) );
-	$node->put_in_container( $container );
-	$node->set_node_ref_attribute( $pp_attr, $pp_node );
-	$node->set_pp_node_attribute_name( $pp_attr );
-	return( $node );
-}
-
-######################################################################
-
 sub test_circular_ref_prevention {
 	my (undef, $class) = @_;
 	my $model = $class->new_container();
+	$model->auto_set_node_ids( 1 );
 
-	my $catalog_bp = make_a_node( 'catalog', $model );
-	$catalog_bp->set_literal_attribute( 'si_name', 'The Catalog Blueprint' );
-	my $owner = make_a_child_node( 'owner', $catalog_bp, 'pp_catalog' );
-	my $schema = make_a_child_node( 'schema', $catalog_bp, 'pp_catalog' );
-	$schema->set_literal_attribute( 'si_name', 'gene' );
+	my $catalog_bp = $model->build_child_node( 'catalog', 'The Catalog Blueprint' );
+	my $owner = $catalog_bp->build_child_node( 'owner' );
+	my $schema = $catalog_bp->build_child_node( 'schema', 'gene' );
 	$schema->set_node_ref_attribute( 'owner', $owner );
 
-	my $vw1 = make_a_child_node( 'view', $schema, 'pp_schema' );
-	$vw1->set_literal_attribute( 'si_name', 'foo' );
+	my $vw1 = $schema->build_child_node( 'view', 'foo' );
 	$vw1->set_enumerated_attribute( 'view_type', 'UPDATE' );
 
-	my $vw2 = make_a_child_node( 'view', $vw1, 'pp_view' );
-	$vw2->set_literal_attribute( 'si_name', 'bar' );
+	my $vw2 = $vw1->build_child_node( 'view', 'bar' );
 	$vw2->set_enumerated_attribute( 'view_type', 'UPDATE' );
 
-	my $vw3 = make_a_child_node( 'view', $vw2, 'pp_view' );
-	$vw3->set_literal_attribute( 'si_name', 'bz' );
+	my $vw3 = $vw2->build_child_node( 'view', 'bz' );
 	$vw3->set_enumerated_attribute( 'view_type', 'UPDATE' );
 
 	my $test1_passed = 0;
